# Copyright (c) 2000-2008, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

Name:           hamcrest
Version:        1.3
Release:        %mkrel 25
Group:          Development/Java
Epoch:          0
Summary:        Library of matchers for building test expressions
License:        BSD
URL:            https://github.com/hamcrest/JavaHamcrest
Source0:        https://github.com/hamcrest/JavaHamcrest/archive/hamcrest-java-%{version}.tar.gz

Source8:        hamcrest-core-MANIFEST.MF
Source9:        hamcrest-library-MANIFEST.MF
Source11:       hamcrest-integration-MANIFEST.MF
Source12:       hamcrest-generator-MANIFEST.MF

Patch0:         %{name}-%{version}-build.patch
Patch1:         %{name}-%{version}-no-jarjar.patch
Patch3:         %{name}-%{version}-javadoc.patch
Patch4:         %{name}-%{version}-qdox-2.0.patch
Patch5:         %{name}-%{version}-fork-javac.patch

Requires:       qdox
Requires:       easymock >= 3.0
Requires:       %{name}-core = %{epoch}:%{version}-%{release}

BuildRequires:  javapackages-local
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  easymock
BuildRequires:  junit
BuildRequires:  qdox
BuildRequires:  testng

BuildArch:      noarch

%description
Provides a library of matcher objects (also known as constraints or predicates)
allowing 'match' rules to be defined declaratively, to be used in other
frameworks. Typical scenarios include testing frameworks, mocking libraries and
UI validation rules.

%package core
Summary:        Core API of hamcrest matcher framework
Obsoletes:      %{name} < 0:1.3-10

%description core
The core API of hamcrest matcher framework to be used by third-party framework providers. 
This includes the a foundation set of matcher implementations for common operations. 

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%package demo
Summary:        Demos for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       junit
Requires:       testng

%description demo
Demonstrations and samples for %{name}.

%prep
%setup -q -n JavaHamcrest-%{name}-java-%{version}

find . -type f -name "*.jar" | xargs -t rm
rm -fr hamcrest-integration/src/main/java/org/hamcrest/integration/JMock1Adapter.java
rm -fr hamcrest-integration/src/main/java/org/hamcrest/JMock1Matchers.java
rm -fr hamcrest-unit-test/src/main/java/org/hamcrest/integration/JMock1AdapterTest.java
# BUILD/hamcrest-1.1/lib/generator/qdox-1.6.1.jar.no
ln -sf $(build-classpath qdox) lib/generator/
# BUILD/hamcrest-1.1/lib/integration/easymock-2.2.jar.no
ln -sf $(build-classpath easymock3) lib/integration/
# BUILD/hamcrest-1.1/lib/integration/jmock-1.10RC1.jar.no
ln -sf $(build-classpath jmock) lib/integration/
# BUILD/hamcrest-1.1/lib/integration/testng-4.6-jdk15.jar.no
ln -sf $(build-classpath testng-jdk15) lib/integration/

%patch0 -p1
%patch1 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

sed -i 's/\r//' LICENSE.txt

# Set target to 1.6 to build with Java 11
sed -i 's/target="1.5"/target="1.6"/' build.xml
# Disable checking of remote javadoc links
sed -i '/link offline/ d' build.xml

%build
export CLASSPATH=$(build-classpath qdox)
export OPT_JAR_LIST="junit ant/ant-junit"
# The unit-test goal is switched off as some tests fail with JDK 7
# see https://github.com/hamcrest/JavaHamcrest/issues/30
ant -Dant.build.javac.source=1.6 -Dversion=%{version} -Dbuild.sysclasspath=last clean core generator library bigjar javadoc

# inject OSGi manifests
jar ufm build/%{name}-core-%{version}.jar %{SOURCE8}
jar ufm build/%{name}-library-%{version}.jar %{SOURCE9}
jar ufm build/%{name}-integration-%{version}.jar %{SOURCE11}
jar ufm build/%{name}-generator-%{version}.jar %{SOURCE12}

%install
sed -i 's/@VERSION@/%{version}/g' pom/*.pom

%mvn_artifact pom/hamcrest-parent.pom

for mod in all core generator library integration; do
    %mvn_artifact pom/hamcrest-$mod.pom build/%{name}-$mod-%{version}.jar
done

%mvn_package :hamcrest-parent core
%mvn_package :hamcrest-core core

%mvn_file ':hamcrest-{*}' %{name}/@1

# demo
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}
cp -pr %{name}-examples $RPM_BUILD_ROOT%{_datadir}/%{name}/

%mvn_install -J build/temp/hamcrest-all-1.3-javadoc.jar.contents/

%files -f .mfiles

%files core -f .mfiles-core
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%files demo
%{_datadir}/%{name}




%changelog
* Sat Sep 05 2020 daviddavid <daviddavid> 0:1.3-25.mga8
+ Revision: 1622302
- Use source/target 1.6 to build against Java 11
- Disable checking of remote javadoc links
- Rebuilt for JDK-11

* Wed Feb 12 2020 umeabot <umeabot> 0:1.3-24.mga8
+ Revision: 1501545
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 0:1.3-23.mga7
+ Revision: 1278650
- Mageia 7 Mass Rebuild

* Wed Oct 04 2017 daviddavid <daviddavid> 0:1.3-22.mga7
+ Revision: 1168349
- Elimitate race condition when injecting JAR manifest (sync with fc27)
- Resolves: rhbz#1495234
- Remove bogus hamcrest-text JAR
- Fix mistake in mvn_artifact invocation
- Install with XMvn
- Update upstream URL
- Build from github source
- Specfile cleanup

* Wed Mar 02 2016 neoclust <neoclust> 0:1.3-15.mga6
+ Revision: 982614
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 0:1.3-14.mga6
+ Revision: 977190
- First rebuild of the java stack
- sync package hamcrest with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Oct 31 2015 daviddavid <daviddavid> 0:1.3-7.mga6
+ Revision: 896847
- sync with fc24:
  * Disable javadoc doclint
  * Add obsoletes in core to the main package to ease updates
  * Split hamcrest-core subpackage to allow other frameworks to reduce deps

* Tue Jan 13 2015 pterjan <pterjan> 0:1.3-6.mga5
+ Revision: 810468
- Sync with Fedora 21

* Wed Oct 15 2014 umeabot <umeabot> 0:1.3-5.mga5
+ Revision: 746551
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:1.3-4.mga5
+ Revision: 680071
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 0:1.3-3.mga4
+ Revision: 537730
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 dmorgan <dmorgan> 0:1.3-2.mga4
+ Revision: 487547
- Update osgi manifests.
  Build against easymock3

* Fri Jul 12 2013 dmorgan <dmorgan> 0:1.3-1.mga4
+ Revision: 453416
- New version

* Sat Jan 12 2013 umeabot <umeabot> 0:1.1-14.mga4
+ Revision: 353073
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 dmorgan <dmorgan> 0:1.1-13.mga3
+ Revision: 325623
- Remove attributes in Export-Package header of hamcrest-core

* Wed Sep 12 2012 dmorgan <dmorgan> 0:1.1-12.mga3
+ Revision: 293019
- Clean specfile

* Fri Jun 29 2012 dmorgan <dmorgan> 0:1.1-11.mga3
+ Revision: 265198
- Rebuild against new java

* Sat Dec 10 2011 dmorgan <dmorgan> 0:1.1-3.mga2
+ Revision: 179953
- Do not BR/R openjdk6 but java >= 0:1.6.0
- Adapt to current guidelines.

* Tue Jan 18 2011 dmorgan <dmorgan> 0:1.1-2.0.4.mga1
+ Revision: 21785
- Fix release
- Sync with fedora
- imported package hamcrest


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.1-2.0.4mdv2011.0
+ Revision: 605850
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.1-2.0.3mdv2010.1
+ Revision: 522835
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0:1.1-2.0.2mdv2010.0
+ Revision: 425139
- rebuild

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 0:1.1-2.0.1mdv2009.0
+ Revision: 264653
- rebuild early 2009.0 package (before pixel changes)

* Wed Apr 16 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.1-1.0.1mdv2009.0
+ Revision: 194992
- BR java-rpmbuild
- add ant.jar to classpath also
- try again to fix ant-launcher
- really add ant-launcher
- add ant-launcher to the classpath
- import hamcrest


